pub struct ApiToken {
pub id: Uuid,
pub org_id: Uuid,
pub user_id: Option<Uuid>,
pub name: String,
pub token_prefix: String,
pub hashed_token: String,
pub scopes: Vec<String>,
pub last_used_at: Option<DateTime<Utc>>,
pub expires_at: Option<DateTime<Utc>>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Expand description
API Token model
Fields
id: Uuidorg_id: Uuiduser_id: Option<Uuid>name: Stringtoken_prefix: Stringhashed_token: Stringscopes: Vec<String>last_used_at: Option<DateTime<Utc>>expires_at: Option<DateTime<Utc>>created_at: DateTime<Utc>updated_at: DateTime<Utc>Implementations
Sourceimpl ApiToken
impl ApiToken
Sourcepub async fn create(
pool: &Pool<Postgres>,
org_id: Uuid,
user_id: Option<Uuid>,
name: &str,
scopes: &[TokenScope],
expires_at: Option<DateTime<Utc>>,
) -> Result<(String, ApiToken), Error>
pub async fn create( pool: &Pool<Postgres>, org_id: Uuid, user_id: Option<Uuid>, name: &str, scopes: &[TokenScope], expires_at: Option<DateTime<Utc>>, ) -> Result<(String, ApiToken), Error>
Create a new API token Returns the full token (only shown once) and the ApiToken record
Sourcepub async fn find_by_prefix(
pool: &Pool<Postgres>,
org_id: Uuid,
prefix: &str,
) -> Result<Option<ApiToken>, Error>
pub async fn find_by_prefix( pool: &Pool<Postgres>, org_id: Uuid, prefix: &str, ) -> Result<Option<ApiToken>, Error>
Find token by prefix (for listing)
Sourcepub async fn find_by_id(
pool: &Pool<Postgres>,
token_id: Uuid,
) -> Result<Option<ApiToken>, Error>
pub async fn find_by_id( pool: &Pool<Postgres>, token_id: Uuid, ) -> Result<Option<ApiToken>, Error>
Find token by ID
Sourcepub async fn find_by_org(
pool: &Pool<Postgres>,
org_id: Uuid,
) -> Result<Vec<ApiToken>, Error>
pub async fn find_by_org( pool: &Pool<Postgres>, org_id: Uuid, ) -> Result<Vec<ApiToken>, Error>
Get all tokens for an organization
Sourcepub async fn verify_token(
pool: &Pool<Postgres>,
token: &str,
) -> Result<Option<ApiToken>, Error>
pub async fn verify_token( pool: &Pool<Postgres>, token: &str, ) -> Result<Option<ApiToken>, Error>
Verify token and return the token record if valid
Sourcepub async fn rotate(
pool: &Pool<Postgres>,
token_id: Uuid,
new_name: Option<&str>,
delete_old: bool,
) -> Result<(String, ApiToken, Option<ApiToken>), Error>
pub async fn rotate( pool: &Pool<Postgres>, token_id: Uuid, new_name: Option<&str>, delete_old: bool, ) -> Result<(String, ApiToken, Option<ApiToken>), Error>
Rotate a token (create new token with same scopes, optionally delete old) Returns the new full token (only shown once) and the new ApiToken record