pub struct Organization {
pub id: Uuid,
pub name: String,
pub slug: String,
pub owner_id: Uuid,
pub plan: String,
pub limits_json: Value,
pub stripe_customer_id: Option<String>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Expand description
Organization model
Fields
id: Uuidname: Stringslug: Stringowner_id: Uuidplan: Stringlimits_json: Valuestripe_customer_id: Option<String>created_at: DateTime<Utc>updated_at: DateTime<Utc>Implementations
Sourceimpl Organization
impl Organization
Sourcepub async fn create(
pool: &Pool<Postgres>,
name: &str,
slug: &str,
owner_id: Uuid,
plan: Plan,
) -> Result<Organization, Error>
pub async fn create( pool: &Pool<Postgres>, name: &str, slug: &str, owner_id: Uuid, plan: Plan, ) -> Result<Organization, Error>
Create a new organization Also creates the owner membership automatically
Sourcepub async fn find_by_id(
pool: &Pool<Postgres>,
id: Uuid,
) -> Result<Option<Organization>, Error>
pub async fn find_by_id( pool: &Pool<Postgres>, id: Uuid, ) -> Result<Option<Organization>, Error>
Find organization by ID
Sourcepub async fn find_by_slug(
pool: &Pool<Postgres>,
slug: &str,
) -> Result<Option<Organization>, Error>
pub async fn find_by_slug( pool: &Pool<Postgres>, slug: &str, ) -> Result<Option<Organization>, Error>
Find organization by slug
Sourcepub async fn find_by_user(
pool: &Pool<Postgres>,
user_id: Uuid,
) -> Result<Vec<Organization>, Error>
pub async fn find_by_user( pool: &Pool<Postgres>, user_id: Uuid, ) -> Result<Vec<Organization>, Error>
Get organizations for a user (as owner or member)
Sourcepub async fn get_or_create_personal_org(
pool: &Pool<Postgres>,
user_id: Uuid,
username: &str,
) -> Result<Organization, Error>
pub async fn get_or_create_personal_org( pool: &Pool<Postgres>, user_id: Uuid, username: &str, ) -> Result<Organization, Error>
Get or create user’s personal organization This ensures every user has at least one org (backward compatibility)