pub struct UserPublicKey {
pub id: Uuid,
pub user_id: Uuid,
pub algorithm: String,
pub public_key_b64: String,
pub label: String,
pub created_at: DateTime<Utc>,
pub revoked_at: Option<DateTime<Utc>>,
pub org_id: Option<Uuid>,
}Fields
id: Uuiduser_id: Uuidalgorithm: Stringpublic_key_b64: Stringlabel: Stringcreated_at: DateTime<Utc>revoked_at: Option<DateTime<Utc>>org_id: Option<Uuid>Optional org tag. When set, the key is also accepted by the
attestation verifier when other members of that org publish and
is visible to org Owners/Admins via the org-scoped listing
endpoint. None keeps the historical user-only behavior.
Implementations