pub struct RedisPool { /* private fields */ }Expand description
Redis connection wrapper
Implementations
Sourceimpl RedisPool
impl RedisPool
Sourcepub fn get_connection(&self) -> Arc<ConnectionManager>
pub fn get_connection(&self) -> Arc<ConnectionManager>
Get a connection for async operations Note: ConnectionManager is already cloneable, so we can use it directly
Sourcepub async fn increment_with_expiry(
&self,
key: &str,
expiry_seconds: u64,
) -> Result<i64>
pub async fn increment_with_expiry( &self, key: &str, expiry_seconds: u64, ) -> Result<i64>
Increment a counter with expiration Returns the new count after increment
Sourcepub async fn get_counter(&self, key: &str) -> Result<i64>
pub async fn get_counter(&self, key: &str) -> Result<i64>
Get a counter value
Sourcepub async fn set_with_expiry(
&self,
key: &str,
value: &str,
expiry_seconds: u64,
) -> Result<()>
pub async fn set_with_expiry( &self, key: &str, value: &str, expiry_seconds: u64, ) -> Result<()>
Set a key with expiration